#
# spec file for package python-aioftp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-aioftp
Version:        0.25.1
Release:        1.1
Summary:        FTP client/server for asyncio
License:        Apache-2.0
URL:            https://github.com/aio-libs/aioftp
Source:         https://files.pythonhosted.org/packages/source/a/aioftp/aioftp-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-siosocks >= 0.2.0
BuildArch:      noarch
BuildRequires:  %{python_module async_timeout >= 4.0.0}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module siosocks >= 0.2.0}
BuildRequires:  %{python_module trustme}
%python_subpackages

%description
aioftp is a python FTP client/server based on asyncio.

%prep
%setup -q -n aioftp-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license license.txt
%{python_sitelib}/aioftp-%{version}*-info
%{python_sitelib}/aioftp

%changelog
* Tue Jun  3 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.25.1
  * do not start explicit tls if implicit mode used (fixes #184) (#185)
- from version 0.25.0
  * client: add partial client support for explicit tls (#183)
- Update BuildRequires from pyproject.toml
* Wed Jan 22 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.24.1
  * server: use single line pasv response (fix #142)
- from versiom 0.24.0
  * remove documentation dependencies from pyproject.toml
    (moved to docs/requirements.txt)
  * include symlink destination in path info for unix legacy mode (#169)
  * update documentation links (#180)
* Wed Oct 23 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.23.1
  * Update ci
- from version 0.23.0
  * server: fix pathlib `relative_to` issue (#179)
  * minimal python version upgraded to 3.9
* Mon Oct  7 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.22.3
  * minimal python version downgraded to 3.8
- from version 0.22.2
  * ci: separate build and publish jobs
- from version 0.22.1
  * docs: update/fix readthedocs configuration
  * ci: fix workflow file extension from `yaml` to `yml`
- from version 0.22.0
  * client.list: fix infinite symlink loop for `.` and `..` on FTP servers
    with UNIX-like filesystem for `client.list(path, recursive=True)`
  * project file structure: refactor to use `pyproject.toml`
  * minimal python version bumped to 3.11
  * ci: update publish/deploy job (#171)
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
- Update BuildRequires from pyproject.toml
* Sat Jan  7 2023 Ben Greiner <code@bnavigator.de>
- Remove 'legacy' pytest-asyncio mode command line argument. It is
  not available anymore, meanwhile upstream uses 'strict' from
  config file.
* Mon Oct 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.21.4
  * setup/tests: set low bound for version of `async-timeout`
  * docs: fix rst link markup
  * docs: add `LIST` parsing warning explanation
  * tests: use `pytest_asyncio` `strict` mode and proper decorations (fixes #155)
* Thu Aug 18 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.21.3
  * server/LIST: prevent broken links are listed, but can't be used
    with stat
  * server: make User.get_permissions async
- Release 0.21.2
  + tests: remove exception representation check
- Release 0.21.1
  * tests: replace more specific ConnectionRefusedError with
    OSError for compatibility with FreeBSD (#152)
- Release 0.21.0
  * server: support PASV response with custom address (#150)
- Release 0.20.1
  * server: fix real directory resolve for windows (#147)
- Release 0.20.0
  * add client argument to set priority of custom list parser
    (parse_list_line_custom_first) (#145)
  * do not ignore failed parsing of list response (#144)
- Enforce legacy pytest-asyncio mode
  * gh#aio-libs/aioftp#155
  * works around gh#pytest-dev/pytest-asyncio#390
* Wed Nov  3 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.19.0
  * add client connection timeout
  * remove explicit coroutine passing to `asyncio.wait`
* Fri Jan 22 2021 andy great <andythe_great@pm.me>
- Add minimum python-siosocks version.
* Thu Jan 21 2021 andy great <andythe_great@pm.me>
- Update to 0.18.1.
  * sync tests with new `siosocks`
  * some docs fixes
- Updates for 0.18.0
  * server: fix `MLSX` time format
  * server: resolve server address from connection
- Updates for 0.17.2
  * server: fix broken `python -m aioftp` after 3.7 migration
- Updates for 0.17.1
  * common/stream: add `readexactly` proxy method
- Updates for 0.17.0
  * tests: fix test_unlink_on_dir on POSIX compatible systems
  * docs: fix extra parentheses
  * client: replace `ClientSession` with `Client.context`
- Updates for 0.16.1
  * client: strip date before parsing
  * client: logger no longer prints out plaintext password
  * client: add custom passive commands to client
- Updates for 0.16.0
  * server: remove obsolete `pass` to `pass_` command renaming
  * client: fix leap year bug at `parse_ls_date` method
  * all: add base exception class
* Thu Jan 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.15.0
  * server: use explicit mapping of available commands for security reasons
  * client: add socks proxy support via siosocks
  * client: add custom list parser
* Thu Nov  7 2019 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Initial version
